==> biings-ds-1.1.1.tgz: package/docs/start.md <==
<h1 class="title is-2">Biings <span class="has-text-weight-light">Design System</span></h1>
<p class="subtitle is-5">
    <span class="has-text-weight-semibold">Biings DS</span> is the design system for Biings applications and web pages. It is a series of components and guidelines used for creating unified UI.
    Avoid creating your own CSS code by combining components and modifiers together.
</p>

<hr>

<div class="columns is-multiline is-mobile is-variable">
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/color" class="box is-well is-relaxed hover-to-popping">
            <img src="media/appcomp.png" width="80"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Colors</div>
                <div class="subtitle is-6">Color brings a design to life.</div>
            </div>
        </a>
    </div>
    <div class="column is-12 is-hidden-desktop"></div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/voice" class="box is-well is-relaxed hover-to-popping">
            <img src="media/voice.png" width="80"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Voice & Tone</div>
                <div class="subtitle is-6">Good design starts with good copy.</div>
            </div>
        </a>
    </div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/illustration" class="box is-well is-relaxed hover-to-popping">
            <img src="media/layout.png" width="80"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Illustrations</div>
                <div class="subtitle is-6">What makes complex ideas more accessible.</div>
            </div>
        </a>
    </div>
    <div class="column is-12 is-hidden-desktop"></div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/avatar" class="box is-well is-relaxed hover-to-popping">
            <img src="media/components.png" width="80"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Components</div>
                <div class="subtitle is-6">All BDS components, with code and usage guidelines.</div>
            </div>
        </a>
    </div>
</div>

<hr>

<div class="box is-bordered is-relaxed">
        <div class="title is-spaced is-3 has-text-weight-light has-text-grey-dark">How to use?
        </div>
        <div class="subtitle is-6 has-text-grey-dark">
            We welcome all feedback, designs, or ideas in order to produce the best possible experience for our users. If you're interested in contributing, check out the **<a href="#/readme">Readme</a>** to get started.
        </div>
</div>

==> biings-ds-1.1.4.tgz: package/docs/start.md <==
<h1 class="title is-2">Biings <span class="has-text-weight-light">Design System</span></h1>
<p class="subtitle is-5">
    <span class="has-text-weight-semibold">Biings DS</span> is the design system for Biings applications and web pages. It is a series of components and guidelines used for creating unified UI.
    Avoid creating your own CSS code by combining components and modifiers together.
</p>

<hr>

<div class="columns is-multiline is-mobile is-variable">
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/color" class="box is-well is-relaxed hover-to-popping">
            <img src="media/appcomp.png" width="80" class="no-zoom"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Colors</div>
                <div class="subtitle is-6">Color brings a design to life.</div>
            </div>
        </a>
    </div>
    <div class="column is-12 is-hidden-desktop"></div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/voice" class="box is-well is-relaxed hover-to-popping">
            <img src="media/voice.png" width="80" class="no-zoom"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Voice & Tone</div>
                <div class="subtitle is-6">Good design starts with good copy.</div>
            </div>
        </a>
    </div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/illustration" class="box is-well is-relaxed hover-to-popping">
            <img src="media/layout.png" width="80" class="no-zoom"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Illustrations</div>
                <div class="subtitle is-6">What makes complex ideas more accessible.</div>
            </div>
        </a>
    </div>
    <div class="column is-12 is-hidden-desktop"></div>
    <div class="column is-half-desktop is-full-tablet">
        <a href="#/avatar" class="box is-well is-relaxed hover-to-popping">
            <img src="media/components.png" width="80" class="no-zoom"/>
            <div>
                <div class="title is-3 has-text-primary has-text-weight-light">Components</div>
                <div class="subtitle is-6">All BDS components, with code and usage guidelines.</div>
            </div>
        </a>
    </div>
</div>

<hr>

<div class="box is-bordered is-relaxed">
    <div class="title is-spaced is-3 has-text-weight-light has-text-grey-darker">How to use?</div>
    <div class="subtitle is-6 has-text-grey-darker">
        We welcome all feedback, designs, or ideas in order to produce the best possible experience for our users. If you're interested in contributing, check out the <a href="#/readme">**Readme**</a> to get started.
    </div>
</div>
